==> ibiz-model-8.1.0.304-sources.jar: net/ibizsys/model/bi/PSSysBICubeMeasureImpl.java <==
package net.ibizsys.model.bi;



public class PSSysBICubeMeasureImpl extends net.ibizsys.model.bi.PSSysBICubeObjectImpl implements net.ibizsys.model.bi.IPSSysBICubeMeasure{

	public final static String ATTR_GETCODENAME = "codeName";
	public final static String ATTR_GETMEASUREFORMULA = "measureFormula";
	public final static String ATTR_GETMEASURETAG = "measureTag";
	public final static String ATTR_GETMEASURETAG2 = "measureTag2";
	public final static String ATTR_GETMEASURETYPE = "measureType";
	public final static String ATTR_GETPSDEFIELD = "getPSDEField";
	public final static String ATTR_GETVALUEFORMAT = "valueFormat";
	public final static String ATTR_ISHIDDENITEM = "hiddenItem";

	public java.lang.String getCodeName(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCODENAME);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getMeasureFormula(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMEASUREFORMULA);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getMeasureTag(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMEASURETAG);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getMeasureTag2(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMEASURETAG2);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getMeasureType(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMEASURETYPE);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.dataentity.defield.IPSDEField psdefield;

	public net.ibizsys.model.dataentity.defield.IPSDEField getPSDEField(){
		if(this.psdefield != null) return this.psdefield;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPSDEFIELD);
		if(value == null){
			return null;
		}
		net.ibizsys.model.dataentity.IPSDataEntity ipsdataentity = getParentPSModelObject(net.ibizsys.model.dataentity.IPSDataEntity.class);
		this.psdefield = ipsdataentity.getPSDEField(value, false);
		return this.psdefield;
	}

	public net.ibizsys.model.dataentity.defield.IPSDEField getPSDEFieldMust(){
		net.ibizsys.model.dataentity.defield.IPSDEField value = this.getPSDEField();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定实体属性");}
		return value;
	}


	public java.lang.String getValueFormat(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETVALUEFORMAT);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public boolean isHiddenItem(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_ISHIDDENITEM);
		if(value == null){
			return false;
		}
		return value.asBoolean();
	}
}

==> ibiz-model-8.1.0.516-sources.jar: net/ibizsys/model/bi/PSSysBICubeMeasureImpl.java <==
package net.ibizsys.model.bi;



public class PSSysBICubeMeasureImpl extends net.ibizsys.model.bi.PSSysBICubeObjectImpl implements net.ibizsys.model.bi.IPSSysBICubeMeasure{

	public final static String ATTR_GETCODENAME = "codeName";
	public final static String ATTR_GETMEASUREFORMULA = "measureFormula";
	public final static String ATTR_GETMEASURETAG = "measureTag";
	public final static String ATTR_GETMEASURETAG2 = "measureTag2";
	public final static String ATTR_GETMEASURETYPE = "measureType";
	public final static String ATTR_GETPSDEFIELD = "getPSDEField";
	public final static String ATTR_GETVALUEFORMAT = "valueFormat";
	public final static String ATTR_ISHIDDENITEM = "hiddenItem";

	public java.lang.String getCodeName(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETCODENAME);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getMeasureFormula(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMEASUREFORMULA);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getMeasureTag(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMEASURETAG);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getMeasureTag2(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMEASURETAG2);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public java.lang.String getMeasureType(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETMEASURETYPE);
		if(value == null){
			return null;
		}
		return value.asText();
	}
	private net.ibizsys.model.dataentity.defield.IPSDEField psdefield;

	public net.ibizsys.model.dataentity.defield.IPSDEField getPSDEField(){
		if(this.psdefield != null) return this.psdefield;
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETPSDEFIELD);
		if(value == null){
			return null;
		}
		net.ibizsys.model.bi.IPSSysBICube ipssysbicube = getParentPSModelObject(net.ibizsys.model.bi.IPSSysBICube.class);
		this.psdefield = ipssysbicube.getPSDataEntityMust().getPSDEField(value, false);
		return this.psdefield;
	}

	public net.ibizsys.model.dataentity.defield.IPSDEField getPSDEFieldMust(){
		net.ibizsys.model.dataentity.defield.IPSDEField value = this.getPSDEField();
		if(value == null){throw new net.ibizsys.model.PSModelException(this, "未指定实体属性");}
		return value;
	}


	public java.lang.String getValueFormat(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_GETVALUEFORMAT);
		if(value == null){
			return null;
		}
		return value.asText();
	}

	public boolean isHiddenItem(){
		com.fasterxml.jackson.databind.JsonNode value = this.getObjectNode().get(ATTR_ISHIDDENITEM);
		if(value == null){
			return false;
		}
		return value.asBoolean();
	}
}
